# ------------------------------------------------------------------------
#   FUNCTIONS
# ------------------------------------------------------------------------
ScratchDir () {
    $ECHO_n "Please specify XCRYSDEN_SCRATCH directory (default: $HOME/xcrys_tmp): "
    read ans
    if [ ! -d ${ans:=$HOME/xcrys_tmp} ]; then
	mkdir ${ans:=$HOME/xcrys_tmp}
    fi
    if [ $? -gt 0 ]; then
	echo "ERROR: can't create directory $ans"
	ScratchDir
    fi
    xc_scratch=${ans:=$HOME/xcrys_tmp}
}

GetProfile () {
    $ECHO_n "Please specify your profile (default $1):"
    read ans
    if [ "$ans" = "" ]; then
	ans=$1
	if [ ! -w "$ans" ]; then
	    echo "$ans is not writable; please specify an alternative profile"
	    GetProfile $profile
	fi
    fi
    if [ \( ! -f "$ans" \) -o \( ! -w "$ans" \) ]; then
	echo "profile $ans does not exists or is not writable; Try again !!!"
	GetProfile $profile
    fi
    profile=$ans
}

# ------------------------------------------------------------------------
#   MAIN
# ------------------------------------------------------------------------
ver=`cat $XCRYSDEN_TOPDIR/version`

if [ \( -d /tmp \) -a \( -w /tmp \) ]; then
    tempdir=/tmp
else
    # set tempdir to $HOME
    tempdir=$HOME
fi

clear
echo "
 
   ========================================================================

    * * * *      XCRYSDEN's Configuration/Installation Utility      * * * * 

   ------------------------------------------------------------------------

                          XCRYSDEN version: $ver

   Please follow the instructions during the configuration procedure !!!
   ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
   
   Report all the problems associated with the installation procedure to 
   Tone.Kokalj@ijs.si
   ========================================================================
   
   Press <Enter> to continue ..." | more
read ans
clear

xc_scratch=$XCRYSDEN_SCRATCH
if [ "$XCRYSDEN_SCRATCH" = "" ]; then
    ScratchDir
fi
XCRYSDEN_SCRATCH=$xc_scratch

user_shell=`echo $SHELL | awk '{n=split($0,shell,"/"); print shell[n]}'`

if [ \( "$user_shell" = "csh" \) -o \( "$user_shell" = "tcsh" \) ]; then
    echo "
#------------------------------------------------------------------------
# this is for XCRYSDEN $VER; added by XCRYSDEN installation on
# $date
#------------------------------------------------------------------------
setenv XCRYSDEN_TOPDIR  $XCRYSDEN_TOPDIR
setenv XCRYSDEN_SCRATCH $xc_scratch
set path = (\$XCRYSDEN_TOPDIR \$path \$XCRYSDEN_TOPDIR/scripts \$XCRYSDEN_TOPDIR/util)
" > $tempdir/xcInstall.$$
    profile=$HOME/.cshrc
else 
    # it is sh-based shell
    echo "
#------------------------------------------------------------------------
# this is for XCRYSDEN $ver; added by XCRYSDEN installation on
# $date
#------------------------------------------------------------------------
XCRYSDEN_TOPDIR=$XCRYSDEN_TOPDIR
XCRYSDEN_SCRATCH=$xc_scratch
export XCRYSDEN_TOPDIR XCRYSDEN_SCRATCH
PATH=\"\$XCRYSDEN_TOPDIR:\$PATH:\$XCRYSDEN_TOPDIR/scripts:\$XCRYSDEN_TOPDIR/util\"
" > $tempdir/xcInstall.$$
    if [ "$user_shell" = "bash" ]; then
	profile=$HOME/.bashrc
    else
	profile=$HOME/.profile
    fi
fi

grep_result=
if [ -f $profile ]; then
    grep_result=`grep XCRYSDEN_TOPDIR $profile`
fi
if [ \( "$xcv" = "" \) -o \( "$grep_result" = "" \) ]; then
    # update profile
    if [ -f $profile ]; then
	if [ ! -w $profile ]; then
	    echo "ERROR: doesn't have a writable permission for file $profile"
	    #GetProfile $profile
	fi
	cp  $profile $profile.orig
    else
	touch $profile.orig
    fi
    $ECHO_n "Updating profile file $profile ... "
    cat $profile.orig $tempdir/xcInstall.$$ > $profile
    if [ $? -eq 0 ]; then
	echo OK
    else
	echo FAILED
    fi
else
    echo "
    ************************************************************************
      WARNING: 
                XCRYSDEN_TOPDIR  enviromental variable is already defined.
    ************************************************************************

    TODO: You will have to edit your profile (i.e. \$HOME/.chsrc or
    \$HOME/.bashrc or \$HOME/.profile) manually and make the XCRYSDEN
    section looks like:
" | cat - $tempdir/xcInstall.$$ | more

    echo "
Press <Enter>  to continue ..."
    read ans
    clear
fi 
rm -f $tempdir/xcInstall.$$;

# if XCRYSDEN_SCRATCH dir doesn't exist, create one
#if [ ! -d "$XCRYSDEN_SCRATCH" ]; then
#    mkdir $XCRYSDEN_SCRATCH
#fi
